@@ -22,9 +22,12 @@ cd "$GBP_SOURCES_DIR"
 # Removing all files in the top folder of the archive.
 find -maxdepth 1 -type f -exec rm -rf {} \;
 
-# Removing all folders exept 'minijinja-py'.
-find -mindepth 1 -maxdepth 1 \( ! -name minijinja-py \) -type d -exec rm -rf {} \;
+# Removing all folders except 'minijinja-py' and 'minijinja-contrib'.
+find -mindepth 1 -maxdepth 1 \( ! -name 'minijinja-py' -a ! -name 'minijinja-contrib' \) -type d -exec rm -rf {} \;
 
-# Moving the content of 'minijinja-py' into the top folder and remove the folder..
+# Moving the content of 'minijinja-py' into the top folder, remove the empty folder.
 mv minijinja-py/* .
 rm -rf minijinja-py
+
+# Remove the symlinking of minijinja-contrib/doc-header.html -> ../doc-header.html.
+rm -f minijinja-contrib/doc-header.html
